@@ -15,13 +15,14 @@
 
 import logging as log
 from typing import Optional
+
 from requests.structures import CaseInsensitiveDict
+
 from hspylib.core.enums.http_method import HttpMethod
 from hspylib.modules.fetch.fetch import fetch
 from hspylib.modules.fetch.http_response import HttpResponse
 
 
-
 def rest_call(
     url: str,
     method: HttpMethod,
@@ -31,7 +32,7 @@ def rest_call(
 
     all_headers = {} if not headers else headers
     all_headers.update({
-        "Content-Type": "text/json",
+        "Content-Type": "application/json",
         "Accept": "*/*"
     })
 
